Documentation
¶
Index ¶
Constants ¶
const DefaultLogProductionTimeout = 10 * time.Second
Variables ¶
This section is empty.
Functions ¶
func LogConfig ¶
func LogConfig(ctx context.Context, timeout time.Duration) *testcontainers.LogConsumerConfig
func WithTestDependancies ¶
func WithTestDependancies(t *testing.T, options []*testdef.DependancyOption, testFn func(t *testing.T, db *testdef.DependancyOption))
WithTestDependancies Creates subtests with each known DependancyOption.
Types ¶
type FrameBaseTestSuite ¶
type FrameBaseTestSuite struct {
suite.Suite
Network *testcontainers.DockerNetwork
Ctrl *gomock.Controller
InitResourceFunc func(ctx context.Context) []testdef.TestResource
// contains filtered or unexported fields
}
FrameBaseTestSuite provides a base test suite with all necessary test components.
func (*FrameBaseTestSuite) Resources ¶
func (s *FrameBaseTestSuite) Resources() []testdef.DependancyConn
func (*FrameBaseTestSuite) SetupSuite ¶
func (s *FrameBaseTestSuite) SetupSuite()
SetupSuite initialises the test environment for the test suite.
func (*FrameBaseTestSuite) TearDownSuite ¶
func (s *FrameBaseTestSuite) TearDownSuite()
TearDownSuite cleans up resources after all tests are completed.
type StdoutLogConsumer ¶
type StdoutLogConsumer struct {
// contains filtered or unexported fields
}
func (*StdoutLogConsumer) Accept ¶
func (s *StdoutLogConsumer) Accept(l testcontainers.Log)
Accept prints the log to stdout.
Click to show internal directories.
Click to hide internal directories.